@@ -471,7 +471,7 @@ _docstring_substitution_definitions = {
                 .. note:: No checks are performed on an existing file
                           to ensure that the weights are appropriate
                           for the source field and the values of the
-                          keyword parameters. Inapproriate weights
+                          keyword parameters. Inappropriate weights
                           will produce incorrect results.
 
                           However, when regridding using weights from
@@ -493,7 +493,7 @@ _docstring_substitution_definitions = {
 
                 The computation of the weights can be much more costly
                 than the regridding itself, in which case reading
-                pre-calcuated weights can improve performance.""",
+                pre-calculated weights can improve performance.""",
     # aggregated_units
     "{{aggregated_units: `str` or `None`, optional}}": """aggregated_units: `str` or `None`, optional
                 The units of the aggregated array. Set to `None` to
