@@ -1,5 +1,6 @@
 import logging
 
+from cfdm import is_log_level_debug, is_log_level_detail
 from cfdm.core import DocstringRewriteMeta
 
 from .constants import (
@@ -147,9 +148,11 @@ class FormulaTerms(metaclass=DocstringRewriteMeta):
             var = None
 
         if var is not None:
-            logger.detail(
-                f"Formula term {term!r}:\n{var.dump(display=False, _level=1)}"
-            )  # pragma: no cover
+            if is_log_level_detail(logger):
+                logger.detail(
+                    f"Formula term {term!r}:\n"
+                    f"{var.dump(display=False, _level=1)}"
+                )  # pragma: no cover
 
             valid_standard_names = formula_terms_standard_names[standard_name][
                 term
@@ -213,10 +216,11 @@ class FormulaTerms(metaclass=DocstringRewriteMeta):
                 bounds = f._Bounds(data=f._Data((0.0, 0.0), units))
                 var.set_bounds(bounds)
 
-            logger.detail(
-                f"Formula term {term!r} (default):\n"
-                f"{var.dump(display=False, _level=1)}"
-            )  # pragma: no cover
+            if is_log_level_detail(logger):
+                logger.detail(
+                    f"Formula term {term!r} (default):\n"
+                    f"{var.dump(display=False, _level=1)}"
+                )  # pragma: no cover
 
         return var, key
 
@@ -254,9 +258,10 @@ class FormulaTerms(metaclass=DocstringRewriteMeta):
             # ------------------------------------------------------------
             # There is a unique computed standard name for this formula
             # ------------------------------------------------------------
-            logger.detail(
-                f"computed_standard_name: {computed_standard_name!r}"
-            )  # pragma: no cover
+            if is_log_level_detail(logger):
+                logger.detail(
+                    f"computed_standard_name: {computed_standard_name!r}"
+                )  # pragma: no cover
 
             return computed_standard_name
 
@@ -311,11 +316,14 @@ class FormulaTerms(metaclass=DocstringRewriteMeta):
                 )
                 break
 
-        logger.detail(
-            "computed_standard_name: {}".format(
-                repr(computed_standard_name) if computed_standard_name else ""
-            )
-        )  # pragma: no cover
+        if is_log_level_detail(logger):
+            logger.detail(
+                "computed_standard_name: {}".format(
+                    repr(computed_standard_name)
+                    if computed_standard_name
+                    else ""
+                )
+            )  # pragma: no cover
 
         return computed_standard_name
 
@@ -352,7 +360,8 @@ class FormulaTerms(metaclass=DocstringRewriteMeta):
             axis = f.get_data_axes(key)
             break
 
-        logger.detail(f"Vertical axis: {axis!r}")  # pragma: no cover
+        if is_log_level_detail(logger):
+            logger.detail(f"Vertical axis: {axis!r}")  # pragma: no cover
 
         return axis
 
@@ -416,10 +425,11 @@ class FormulaTerms(metaclass=DocstringRewriteMeta):
 
             eta_axes = eta_axes2
 
-        logger.debug(
-            f"Transposed domain ancillary 'eta': {eta!r}\n"
-            f"Transposed domain ancillary 'eta' axes: {eta_axes!r}"
-        )  # pragma: no cover
+        if is_log_level_debug(logger):
+            logger.debug(
+                f"Transposed domain ancillary 'eta': {eta!r}\n"
+                f"Transposed domain ancillary 'eta' axes: {eta_axes!r}"
+            )  # pragma: no cover
 
         return eta, eta_axes
 
@@ -488,9 +498,10 @@ class FormulaTerms(metaclass=DocstringRewriteMeta):
 
             computed_axes = tuple([computed_axes[i] for i in iaxes])
 
-        logger.detail(
-            f"Non-parametric coordinate axes: {computed_axes!r}"
-        )  # pragma: no cover
+        if is_log_level_detail(logger):
+            logger.detail(
+                f"Non-parametric coordinate axes: {computed_axes!r}"
+            )  # pragma: no cover
 
         return computed, computed_axes
 
@@ -2095,9 +2106,10 @@ class FormulaTerms(metaclass=DocstringRewriteMeta):
         )
 
         if standard_name is not None:
-            logger.detail(
-                f"standard_name: {standard_name!r}"
-            )  # pragma: no cover
+            if is_log_level_detail(logger):
+                logger.detail(
+                    f"standard_name: {standard_name!r}"
+                )  # pragma: no cover
 
             if standard_name in cls.standard_names:
                 # --------------------------------------------------------
