@@ -6,7 +6,6 @@ faulthandler.enable()  # to debug seg faults and timeouts
 
 import cf
 
-
 # Note: it is important we test on the cf logging config rather than the
 # generic Python module logging (i.e. 'cf.logging' not just 'logging').
 # Also, mimic the use in the codebase by using a module-specific logger:
@@ -32,11 +31,14 @@ class dummyClass:
         error."""
         if traceback:
             cf.functions._DEPRECATION_ERROR_KWARGS(
-                self, "another_func", traceback=True
+                self,
+                "another_func",
+                traceback=True,
+                version="some version",
             )
         return good_kwarg
 
-    @cf.decorators._deprecated_kwarg_check("traceback")
+    @cf.decorators._deprecated_kwarg_check("traceback", version="some version")
     def decorated_func_2(self, good_kwarg=True, traceback=False):
         """Dummy function equivalent to 'func_2', but a decorator
         manages the logic to raise the error on use of a deprecated
@@ -45,7 +47,9 @@ class dummyClass:
 
     # Not testing 'bad_kwarg' here other than to the extent that it does not
     # stop 'traceback from causing the expected deprecation-related error.
-    @cf.decorators._deprecated_kwarg_check("traceback", "bad_kwarg")
+    @cf.decorators._deprecated_kwarg_check(
+        "traceback", "bad_kwarg", version="some version"
+    )
     def multikwarg_decorated_func_2(
         self, good_kwarg=True, traceback=False, bad_kwarg=False
     ):
@@ -118,10 +122,10 @@ class DecoratorsTest(unittest.TestCase):
         # should be registered within the log message:
         example_class = dummyClass()
         log_message = [
-            "WARNING:{}:{}".format(log_name, example_class.warning_message),
-            "INFO:{}:{}".format(log_name, example_class.info_message),
-            "DETAIL:{}:{}".format(log_name, example_class.detail_message),
-            "DEBUG:{}:{}".format(log_name, example_class.debug_message),
+            f"WARNING:{log_name}:{example_class.warning_message}",
+            f"INFO:{log_name}:{example_class.info_message}",
+            f"DETAIL:{log_name}:{example_class.detail_message}",
+            f"DEBUG:{log_name}:{example_class.debug_message}",
         ]
 
         for level in levels:
@@ -148,7 +152,7 @@ class DecoratorsTest(unittest.TestCase):
             # all messages should appear, regardless of global log_level:
             for attr in (-1, "DEBUG", "debug", "Debug", "DeBuG"):
                 test_class.verbose = attr
-                with self.assertLogs(level=cf.log_level().value) as catch:
+                with self.assertLogs(level=-1) as catch:
                     test_class.decorated_logging_func()
                     for msg in log_message:
                         self.assertIn(msg, catch.output)
@@ -158,7 +162,7 @@ class DecoratorsTest(unittest.TestCase):
             # regardless of global log_level value set:
             for attr in (1, "WARNING", "warning", "Warning", "WaRning"):
                 test_class.verbose = attr
-                with self.assertLogs(level=cf.log_level().value) as catch:
+                with self.assertLogs(level=1) as catch:
                     test_class.decorated_logging_func()
                     for msg in log_message:
                         if msg.split(":")[0] == "WARNING":
@@ -170,7 +174,7 @@ class DecoratorsTest(unittest.TestCase):
 
             # ... verbose=2 should be equivalent to verbose=3 now:
             test_class.verbose = True
-            with self.assertLogs(level=cf.log_level().value) as catch:
+            with self.assertLogs(level=3) as catch:
                 test_class.decorated_logging_func()
                 for msg in log_message:
                     if msg.split(":")[0] == "DEBUG":
