@@ -681,13 +681,6 @@ class read_writeTest(unittest.TestCase):
         cf.read(tmpfileh)[0]
         c = cf.read(tmpfilec)[0]
 
-        # Case (2) as above, so the right error should be raised on read
-        with self.assertRaises(ValueError):
-            cf.read(tmpfileh2)[0]
-
-        with self.assertRaises(ValueError):
-            cf.read(tmpfilec2)[0]
-
         self.assertTrue(f0.equals(f, verbose=2))
 
         self.assertTrue(
@@ -917,6 +910,14 @@ class read_writeTest(unittest.TestCase):
         self.assertFalse(g.array.count())
         self.assertTrue(g.construct("grid_latitude").array.count())
 
+    def test_read_url(self):
+        """Test reading urls."""
+        for scheme in ("http", "https"):
+            remote = f"{scheme}://psl.noaa.gov/thredds/dodsC/Datasets/cru/crutem5/Monthlies/air.mon.anom.nobs.nc"
+            # Check that cf can access it
+            f = cf.read(remote)
+            self.assertEqual(len(f), 1)
+
 
 if __name__ == "__main__":
     print("Run date:", datetime.datetime.now())
